# emdfile tests

To run tests
- setup an environment
- install emdfile in local editable mode, `pip install -e .`

## TODO - setup default test files
- ensure pytest and gdown are installed, `pip install pytest gdown`
- run setup_tests.py to download data
- run pytest in ./test/


